[![Jazzband](https://jazzband.co/static/img/jazzband.svg)](https://jazzband.co/)

This is a [Jazzband](https://jazzband.co/) project. By contributing you agree
to abide by the [Contributor Code of Conduct](https://jazzband.co/about/conduct)
and follow the [guidelines](https://jazzband.co/about/guidelines).

Also, here are a few additional or emphasized guidelines to follow:
- Always provide tests for your changes.
- Add your changes to the [CHANGELOG](CHANGELOG.md).
- Wait for the review of at least one other contributor before merging (even if you're a Jazzband member).

The only exception to those guidelines is for trivial changes, such as
documentation corrections or contributions that do not change pip-tools itself.

Contributions following these guidelines are always welcomed, encouraged and appreciated.
